@@ -15,7 +15,6 @@ from openstack import resource
 
 
 class Port(_common.ListMixin, resource.Resource):
-
     resources_key = 'ports'
     base_path = '/ports'
 
@@ -30,7 +29,9 @@ class Port(_common.ListMixin, resource.Resource):
     commit_jsonpatch = True
 
     _query_mapping = resource.QueryParameters(
-        'address', 'node', 'portgroup',
+        'address',
+        'node',
+        'portgroup',
         fields={'type': _common.fields_type},
         node_id='node_uuid',
     )
